@@ -2,11 +2,11 @@ module Rabl
   class Digestor < ActionView::Digestor
     # Override the original digest function to ignore partial which
     # rabl doesn't use the Rails conventional _ symbol.
-    if Rails.version.to_s >= '4.1'
+    if Gem::Version.new(Rails.version) >= Gem::Version.new('4.1')
       def self.digest(options = {})
         cache_key = [options[:name]] + Array.wrap(options[:dependencies])
         @@cache[cache_key.join('.')] ||= begin
-          Digestor.new({ name: options[:name], finder: options[:finder] }.merge!(options)).digest
+          Digestor.new({ :name => options[:name], :finder => options[:finder] }.merge!(options)).digest
         end
       end
     else
@@ -20,9 +20,9 @@ module Rabl
 
     private
       def dependency_digest
-        template_digests = dependencies.collect do |template_name|
-          if Rails.version.to_s >= '4.1'
-            Digestor.digest(name: template_name, finder: finder)
+        template_digests = (dependencies - [template.virtual_path]).collect do |template_name|
+          if Gem::Version.new(Rails.version) >= Gem::Version.new('4.1')
+            Digestor.digest(:name => template_name, :finder => finder)
           else
             Digestor.digest(template_name, format, finder)
           end
