@@ -11,8 +11,8 @@ if defined?(Tilt)
       @engine = ::Rabl::Engine.new(data, options)
     end
 
-    def evaluate(scope, locals, &block)
-      @engine.render(scope, locals, &block)
+    def evaluate(context_scope, locals, &block)
+      @engine.apply(context_scope, locals, &block).render
     end
   end
 
@@ -52,11 +52,12 @@ if defined?(ActionView) && defined?(Rails) && Rails.version.to_s =~ /^[34]/
           source = template.source
 
           %{ ::Rabl::Engine.new(#{source.inspect}).
-              render(self, assigns.merge(local_assigns)) }
+              apply(self, assigns.merge(local_assigns)).
+              render }
         end # call
       end # rabl class
     end # handlers
   end
 
   ActionView::Template.register_template_handler :rabl, ActionView::Template::Handlers::Rabl
-end
\ No newline at end of file
+end
