@@ -57,7 +57,7 @@ context "Rabl::Engine" do
         template.instance_eval('@engine')
       end
 
-      asserts_topic.assigns(:_cache) { ['foo', nil] }
+      asserts_topic.assigns(:_cache_key) { 'foo' }
     end
 
     context "with cache and options" do
@@ -69,7 +69,8 @@ context "Rabl::Engine" do
         template.instance_eval('@engine')
       end
 
-      asserts_topic.assigns(:_cache) { ['foo', { :expires_in => 'bar' }] }
+      asserts_topic.assigns(:_cache_key) { 'foo' }
+      asserts_topic.assigns(:_cache_options) { { :expires_in => 'bar' } }
     end
 
     context "without cache" do
@@ -79,7 +80,7 @@ context "Rabl::Engine" do
         template.instance_eval('@engine')
       end
 
-      denies(:instance_variable_defined?, :@_cache)
+      denies(:instance_variable_defined?, :@_cache_key)
     end
   end
 
@@ -442,9 +443,12 @@ context "Rabl::Engine" do
         scope = Object.new
         @user = User.new(:name => 'leo', :city => 'LA', :age => 12)
         scope.instance_variable_set :@user, @user
+        e = Rabl::Engine.new(nil)
+        mock(e).render.returns({ :name => 'leo', :city => 'LA', :age => 12 })
+
         any_instance_of(Rabl::Engine) do |b|
           mock(b).fetch_source("foo/bar", :view_path => nil).once
-          mock(b).object_to_hash(@user, :locals => { :foo => "bar" }, :source => nil, :source_location => nil, :template => 'foo/bar').returns({ :name => 'leo', :city => 'LA', :age => 12 })
+          mock(b).object_to_engine(@user, :locals => { :foo => "bar" }, :source => nil, :source_location => nil, :template => 'foo/bar').returns(e)
         end
         JSON.parse(template.render(scope))
       end.equals JSON.parse("{ \"foo\" : {\"name\":\"leo\",\"city\":\"LA\",\"age\":12} }")
